Garfield.model.Garfield.Garfield
================================

.. currentmodule:: Garfield.model.Garfield

.. autoclass:: Garfield

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Garfield.__init__
      ~Garfield.add_module
      ~Garfield.apply
      ~Garfield.bfloat16
      ~Garfield.buffers
      ~Garfield.children
      ~Garfield.compile
      ~Garfield.cpu
      ~Garfield.cuda
      ~Garfield.double
      ~Garfield.eval
      ~Garfield.extra_repr
      ~Garfield.float
      ~Garfield.forward
      ~Garfield.get_buffer
      ~Garfield.get_extra_state
      ~Garfield.get_latent_representation
      ~Garfield.get_parameter
      ~Garfield.get_submodule
      ~Garfield.half
      ~Garfield.ipu
      ~Garfield.label_transfer
      ~Garfield.load_query_data
      ~Garfield.load_state_dict
      ~Garfield.modules
      ~Garfield.named_buffers
      ~Garfield.named_children
      ~Garfield.named_modules
      ~Garfield.named_parameters
      ~Garfield.parameters
      ~Garfield.plot_loss_curves
      ~Garfield.register_backward_hook
      ~Garfield.register_buffer
      ~Garfield.register_forward_hook
      ~Garfield.register_forward_pre_hook
      ~Garfield.register_full_backward_hook
      ~Garfield.register_full_backward_pre_hook
      ~Garfield.register_load_state_dict_post_hook
      ~Garfield.register_module
      ~Garfield.register_parameter
      ~Garfield.register_state_dict_pre_hook
      ~Garfield.requires_grad_
      ~Garfield.save
      ~Garfield.set_extra_state
      ~Garfield.setup_layers
      ~Garfield.share_memory
      ~Garfield.state_dict
      ~Garfield.to
      ~Garfield.to_empty
      ~Garfield.train
      ~Garfield.type
      ~Garfield.xpu
      ~Garfield.zero_grad
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Garfield.T_destination
      ~Garfield.call_super_init
      ~Garfield.dump_patches
      ~Garfield.training
   
   